@@ -15,7 +15,7 @@ LOG = logging.getLogger(__name__)
 _DID_LOG_UNABLE_TO_CACHE = False
 
 
-def get_pkg_unique_identifier():
+def get_pkg_unique_identifier() -> str:
     """
     Generate an identifier unique to the python version, tldextract version, and python instance
 
@@ -46,7 +46,7 @@ def get_pkg_unique_identifier():
     return pkg_identifier
 
 
-def get_cache_dir():
+def get_cache_dir() -> str:
     """
     Get a cache dir that we have permission to write to
 
@@ -92,13 +92,12 @@ class DiskCache:
         if not os.path.isfile(cache_filepath):
             raise KeyError("namespace: " + namespace + " key: " + repr(key))
         try:
-            with open(cache_filepath) as cache_file:  # pylint: disable=unspecified-encoding
+            # pylint: disable-next=unspecified-encoding
+            with open(cache_filepath) as cache_file:
                 return json.load(cache_file)
         except (OSError, ValueError) as exc:
             LOG.error("error reading TLD cache file %s: %s", cache_filepath, exc)
-            raise KeyError(  # pylint: disable=raise-missing-from
-                "namespace: " + namespace + " key: " + repr(key)
-            )
+            raise KeyError("namespace: " + namespace + " key: " + repr(key)) from None
 
     def set(self, namespace, key, value):
         """Set a value in the disk cache"""
@@ -108,7 +107,8 @@ class DiskCache:
 
         try:
             _make_dir(cache_filepath)
-            with open(cache_filepath, "w") as cache_file:  # pylint: disable=unspecified-encoding
+            # pylint: disable-next=unspecified-encoding
+            with open(cache_filepath, "w") as cache_file:
                 json.dump(value, cache_file)
         except OSError as ioe:
             global _DID_LOG_UNABLE_TO_CACHE  # pylint: disable=global-statement
@@ -183,6 +183,8 @@ class DiskCache:
 
             return func(**kwargs)
 
+        # Disable lint of 3rd party (see also https://github.com/tox-dev/py-filelock/issues/102)
+        # pylint: disable-next=abstract-class-instantiated
         with FileLock(lock_path, timeout=self.lock_timeout):
             try:
                 result = self.get(namespace=namespace, key=key_args)
